/* 
  Version.m

  Barry McMullin <mcmullin@eeng.dcu.ie>
  16-OCT-1996

*/

#import "Version.h"

@implementation Version

static int major = 0;
static int minor = 5;
static int patch = 5;
static char versionString[50]; // Defensive => longer than necessary...

+(char *) getVersionString {
  sprintf(versionString, "SCL v%d.%02d.%02d", major, minor, patch);
  return versionString;
}

+(int) getMajorVersion {
  return major;
}

+(int) getMinorVersion {
  return minor;
}

+(int) getPatchVersion {
  return patch;
}

+(void) printCopyright {
  printf("\n\n");
  printf([self getVersionString]);
  printf(
     " - An artificial chemistry simulation.\n"
     "Copyright (C) 1996 Barry McMullin\n" 
     "http://www.eeng.dcu.ie/~mcmullin\n\n");

  printf(
     "SWARM kernel Copyright (C) 1996 Santa Fe Institute\n"
     "http://www.santafe.edu\n\n");

  printf(   
     "This program is free software; you can redistribute it and/or modify\n"
     "it under the terms of the GNU General Public License as published by\n"
     "the Free Software Foundation; either version 2 of the License, or\n"
     "(at your option) any later version.\n\n");
  printf(   
     "This program is distributed in the hope that it will be useful,\n"
     "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
     "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
     "GNU General Public License for more details.\n\n");
  printf(   
     "You should have received a copy of the GNU General Public License\n"
     "along with this program in the file LICENSE.TXT; if not,\n" 
     "write to the Free Software Foundation, Inc.,\n"
     "59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n\n");
}

@end
